@@ -9,6 +9,7 @@ from SoftLayer.managers.storage import StorageManager
 from SoftLayer.managers import storage_utils
 from SoftLayer import utils
 
+
 # pylint: disable=too-many-public-methods
 
 
@@ -25,12 +26,13 @@ class BlockStorageManager(StorageManager):
         """
         return self.get_volume_count_limits()
 
-    def list_block_volumes(self, datacenter=None, username=None, storage_type=None, **kwargs):
+    def list_block_volumes(self, datacenter=None, username=None, storage_type=None, order=None, **kwargs):
         """Returns a list of block volumes.
 
         :param datacenter: Datacenter short name (e.g.: dal09)
         :param username: Name of volume.
         :param storage_type: Type of volume: Endurance or Performance
+        :param order: Volume order id.
         :param kwargs:
         :return: Returns a list of block volumes.
         """
@@ -67,8 +69,12 @@ class BlockStorageManager(StorageManager):
             _filter['iscsiNetworkStorage']['username'] = \
                 (utils.query_filter(username))
 
+        if order:
+            _filter['iscsiNetworkStorage']['billingItem']['orderItem'][
+                'order']['id'] = (utils.query_filter(order))
+
         kwargs['filter'] = _filter.to_dict()
-        return self.client.call('Account', 'getIscsiNetworkStorage', **kwargs)
+        return self.client.call('Account', 'getIscsiNetworkStorage', iter=True, **kwargs)
 
     def get_block_volume_details(self, volume_id, **kwargs):
         """Returns details about the specified volume.
@@ -191,3 +197,23 @@ class BlockStorageManager(StorageManager):
         if results:
             return [result['id'] for result in results]
         return []
+
+    def get_cloud_list(self):
+        """Returns a list cloud object storage.
+
+        return: Returns a list cloud object storage.
+        """
+
+        mask = 'mask[id,username,billingItem,storageType, notes]'
+
+        return self.client.call('Account', 'getHubNetworkStorage', mask=mask)
+
+    def get_buckets(self, object_id):
+        """Return  buckets data of the cloud storage.
+
+        :param object_id cloud object storage identifier
+
+        Returns: Get buckets
+
+        """
+        return self.client.call('SoftLayer_Network_Storage_Hub_Cleversafe_Account', 'getBuckets', id=object_id)
