@@ -53,7 +53,7 @@ class UserManager(utils.IdentifierMixin, object):
 
         if objectmask is None:
             objectmask = """mask[id, username, displayName, userStatus[name], hardwareCount, virtualGuestCount,
-                                 email, roles]"""
+                                 email, roles, externalBindingCount,apiAuthenticationKeyCount]"""
 
         return self.account_service.getUsers(mask=objectmask, filter=objectfilter)
 
@@ -392,6 +392,60 @@ class UserManager(utils.IdentifierMixin, object):
 
         return overrides_list
 
+    def remove_hardware_access(self, user_id, hardware_id):
+        """Remove hardware from a portal user’s hardware access list.
+
+        :param int user_id:
+        :param int hardware_id
+
+        :returns: true
+        """
+        return self.user_service.removeHardwareAccess(hardware_id, id=user_id)
+
+    def remove_virtual_access(self, user_id, virtual_id):
+        """Remove hardware from a portal user’s virtual guests access list.
+
+        :param int user_id:
+        :param int hardware_id
+
+        :returns: true
+        """
+        return self.user_service.removeVirtualGuestAccess(virtual_id, id=user_id)
+
+    def remove_dedicated_access(self, user_id, dedicated_id):
+        """Remove hardware from a portal user’s dedicated host access list.
+
+        :param int user_id:
+        :param int dedicated_id
+
+        :returns: true
+        """
+        return self.user_service.removeDedicatedHostAccess(dedicated_id, id=user_id)
+
+    def get_user_hardware(self, user_id):
+        """User Hardware list.
+
+        :param int user_id:
+        :return: List hardware relate to user
+        """
+        return self.user_service.getHardware(id=user_id)
+
+    def get_user_dedicated_host(self, user_id):
+        """User dedicate host list.
+
+        :param int user_id:
+        :return: List dedicated host relate to user
+        """
+        return self.user_service.getDedicatedHosts(id=user_id)
+
+    def get_user_virtuals(self, user_id):
+        """User virtual guest list.
+
+        :param int user_id:
+        :return: List virtual guest relate to user
+        """
+        return self.user_service.getVirtualGuests(id=user_id)
+
 
 def _keyname_search(haystack, needle):
     for item in haystack:
